### 0.12.3 {small}`2025-04-11`

```{rubric} Bug fixes
```
* Fixed `harmony_integrate` breakage caused by undocumented changes to fused kernel float handling in `CuPy 13.4.1` {pr}`351` {smaller}`S Dicks`
